==> PyQtGuiLib-0.0.1.4.tar.gz: PyQtGuiLib-0.0.1.4/PyQtGuiLib/header/Qt/qtWidgets.py <==
from PyQtGuiLib.header.versions import PYQT_VERSIONS
if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect
    )

if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect
    )

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect
    )

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect
    )

==> PyQtGuiLib-0.0.5.0.tar.gz: PyQtGuiLib-0.0.5.0/PyQtGuiLib/header/Qt/qtWidgets.py <==
from PyQtGuiLib.header.versions import PYQT_VERSIONS
if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider
    )

if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider
)

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider
    )

if PYQT_VERSIONS == "PySide6":
    from PySide6.QtWidgets import (
        QApplication,
        QWidget,
        QFrame,
        QStackedWidget,
        QLabel,
        QPushButton,
        QLineEdit,
        QTextBrowser,
        QGroupBox,
        QGridLayout,
        QVBoxLayout,
        QHBoxLayout,
        QCheckBox,
        QInputDialog,
        QComboBox,
        QMenu,
        QTableWidget,
        QScrollArea,
        QWidgetItem,
        QSplitter,
        QGraphicsOpacityEffect,
        QMainWindow,
        QDesktopWidget,
        QGraphicsDropShadowEffect,
        QSlider
    )
